@@ -34,6 +34,9 @@ import (
 	controllertesting "knative.dev/eventing-kafka/pkg/channel/distributed/controller/testing"
 	fakeKafkaClient "knative.dev/eventing-kafka/pkg/client/injection/client/fake"
 	_ "knative.dev/eventing-kafka/pkg/client/injection/informers/messaging/v1beta1/kafkachannel/fake" // Knative Fake Informer Injection
+	"knative.dev/eventing-kafka/pkg/common/configmaploader"
+	fakeConfigmapLoader "knative.dev/eventing-kafka/pkg/common/configmaploader/fake"
+	commonconstants "knative.dev/eventing-kafka/pkg/common/constants"
 	commontesting "knative.dev/eventing-kafka/pkg/common/testing"
 	"knative.dev/pkg/client/injection/kube/client/fake"
 	_ "knative.dev/pkg/client/injection/kube/informers/apps/v1/deployment/fake" // Knative Fake Informer Injection
@@ -59,11 +62,19 @@ func TestNewController(t *testing.T) {
 	assert.NotNil(t, fakeInformers)
 
 	// Add The Fake K8S Clientset To The Context (Populated With ConfigMap)
-	configMap := commontesting.GetTestSaramaConfigMap(controllertesting.SaramaConfigYaml, controllertesting.ControllerConfigYaml)
+	configMap := commontesting.GetTestSaramaConfigMap(
+		commonconstants.CurrentConfigVersion,
+		controllertesting.SaramaConfigYaml,
+		controllertesting.ControllerConfigYaml)
 	secret := controllertesting.NewKafkaSecret(controllertesting.WithKafkaSecretFinalizer)
 	ctx, fakeClientset := fake.With(ctx, configMap, secret)
 	assert.NotNil(t, fakeClientset)
 
+	configmapLoader := fakeConfigmapLoader.NewFakeConfigmapLoader()
+	configmapLoader.Register(commonconstants.SettingsConfigMapMountPath, configMap.Data)
+
+	ctx = context.WithValue(ctx, configmaploader.Key{}, configmapLoader.Load)
+
 	// Add The Fake Kafka Clientset To The Context (Empty)
 	ctx, fakeKafkaClientset := fakeKafkaClient.With(ctx)
 	assert.NotNil(t, fakeKafkaClientset)
